@@ -226,7 +226,14 @@ class JIRAIssueForm(forms.Form):
                     # None values
                     very_clean.pop(field, None)
 
-        very_clean["issuetype"] = {"id": very_clean["issuetype"]}
+        if not hasattr(very_clean["issuetype"], "id"):
+            # something fishy is going on with this field, working on some JIRA
+            # instances, and some not.
+            # testing against 5.1.5 does not convert (perhaps is no longer included
+            # in the projectmeta API call, and would normally be converted in the
+            # above clean method.)
+            very_clean["issuetype"] = {"id": very_clean["issuetype"]}
+
         very_clean.pop("project_key", None)
 
         return very_clean
